
import { Link } from 'react-router-dom';
import { useAuth } from '@/contexts/AuthContext';
import { Avatar, AvatarFallback, AvatarImage } from "@/components/ui/avatar";
import { Button } from "@/components/ui/button";
import {
  Sheet,
  SheetContent,
  SheetDescription,
  SheetHeader,
  SheetTitle,
  SheetTrigger
} from "@/components/ui/sheet";
import { Menu, User, LogOut, CreditCard } from 'lucide-react';
import { toast } from 'sonner';

// Helper function to get user initials for avatar
const getUserInitials = (user: any): string => {
  if (user?.user_metadata?.name) {
    return user.user_metadata.name
      .split(' ')
      .map((part: string) => part[0])
      .join('')
      .toUpperCase()
      .substring(0, 2);
  }
  
  if (user?.email) {
    return user.email.substring(0, 2).toUpperCase();
  }
  
  return "FT";
};

const MobileMenu = () => {
  const { user, logout, isAuthenticated } = useAuth();

  const handleLogout = async () => {
    try {
      await logout();
      toast.success("You have been logged out successfully");
      window.location.href = '/sign-in';
    } catch (error) {
      console.error("Logout error:", error);
      toast.error("Failed to log out. Please try again.");
    }
  };

  return (
    <Sheet>
      <SheetTrigger className="md:hidden">
        <Menu className="h-6 w-6 text-gray-300" />
      </SheetTrigger>
      <SheetContent side="right" className="w-64 bg-background border-l border-brand-maroon/30">
        <SheetHeader>
          <SheetTitle>Menu</SheetTitle>
          <SheetDescription>
            Explore FinTap by CIFT
          </SheetDescription>
        </SheetHeader>
        <div className="flex flex-col space-y-4 mt-4">
          {isAuthenticated ? (
            <>
              <div className="px-4 py-3 border-b border-brand-maroon/20">
                <div className="flex items-center space-x-3">
                  <Avatar className="h-10 w-10 border-2 border-brand-maroon">
                    <AvatarImage src={user?.user_metadata?.avatar_url || ""} alt={user?.user_metadata?.name || "User Avatar"} />
                    <AvatarFallback className="bg-brand-maroon text-white">{getUserInitials(user)}</AvatarFallback>
                  </Avatar>
                  <div>
                    <p className="text-sm font-medium">{user?.user_metadata?.name || "User"}</p>
                    <p className="text-xs text-muted-foreground">{user?.email}</p>
                  </div>
                </div>
              </div>
              <Link to="/assessment" className="flex items-center px-4 py-2 text-sm hover:bg-muted/50 rounded-md">
                <CreditCard className="mr-2 h-4 w-4" />
                Assessment
              </Link>
              <Button variant="destructive" size="sm" className="mx-4 bg-brand-red hover:bg-brand-red/90" onClick={handleLogout}>
                <LogOut className="mr-2 h-4 w-4" />
                Log Out
              </Button>
            </>
          ) : (
            <>
              <Link to="/sign-in" className="flex items-center px-4 py-2 text-sm hover:bg-muted/50 rounded-md">
                <User className="mr-2 h-4 w-4" />
                Sign In
              </Link>
              <Link to="/sign-up" className="flex items-center px-4 py-2 text-sm hover:bg-muted/50 rounded-md">
                <User className="mr-2 h-4 w-4" />
                Sign Up
              </Link>
            </>
          )}
          <div className="px-4 py-2 border-t border-brand-maroon/20 mt-2 pt-4">
            <p className="text-sm font-medium mb-2">Contact CIFT</p>
            <div className="space-y-2 text-sm">
              <p>Professor MS Sobhan</p>
              <p>Founder & CEO</p>
              <a href="mailto:ceo@ciftbd.com" className="block text-brand-red">ceo@ciftbd.com</a>
              <a href="tel:+8801754459594" className="block text-brand-red">+880 1754 459594</a>
            </div>
          </div>
        </div>
      </SheetContent>
    </Sheet>
  );
};

export default MobileMenu;
